@@ -1,7 +1,7 @@
 package Bencher::Scenario::SetOperationModules;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -251,11 +251,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenario::SetOperationModules
+Bencher::Scenario::SetOperationModules - Benchmark Perl set operation (union, intersection, diff, symmetric diff) modules
 
 =head1 VERSION
 
-This document describes version 0.08 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2016-01-05.
+This document describes version 0.09 of Bencher::Scenario::SetOperationModules (from Perl distribution Bencher-Scenario-SetOperationModules), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -271,29 +271,31 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 BENCHMARKED MODULES
 
-L<Array::Utils> 0.5
-
-L<Set::Scalar> 1.29
-
-L<List::MoreUtils::PP> 0.413
-
-L<List::MoreUtils> 0.413
-
-L<Array::Set> 0.02
-
-L<Set::Array> 0.30
+Version numbers shown below are the versions used when running the sample benchmark.
 
 L<Array::AsObject> 1.02
 
+L<Array::Set> 0.02
+
+L<Array::Utils> 0.5
+
+L<List::MoreUtils> 0.413
+
+L<List::MoreUtils::PP> 0.413
+
+L<Set::Array> 0.30
+
 L<Set::Object> 1.35
 
-L<Set::Tiny> 0.03
+L<Set::Scalar> 1.29
+
+L<Set::Tiny> 0.04
 
 =head1 BENCHMARK PARTICIPANTS
 
 =over
 
-=item * Array::Utils::unique (perl_code)
+=item * Array::Utils::unique (perl_code) [op:union]
 
 Code template:
 
@@ -301,7 +303,7 @@ Code template:
 
 
 
-=item * Set::Scalar::union (perl_code)
+=item * Set::Scalar::union (perl_code) [op:union]
 
 Code template:
 
@@ -309,7 +311,7 @@ Code template:
 
 
 
-=item * List::MoreUtils::PP::uniq (perl_code)
+=item * List::MoreUtils::PP::uniq (perl_code) [op:union]
 
 Function call template:
 
@@ -317,7 +319,7 @@ Function call template:
 
 
 
-=item * List::MoreUtils::XS::uniq (perl_code)
+=item * List::MoreUtils::XS::uniq (perl_code) [op:union]
 
 Function call template:
 
@@ -325,7 +327,7 @@ Function call template:
 
 
 
-=item * Array::Set::set_union (perl_code)
+=item * Array::Set::set_union (perl_code) [op:union]
 
 Function call template:
 
@@ -333,7 +335,7 @@ Function call template:
 
 
 
-=item * Set::Array::union (perl_code)
+=item * Set::Array::union (perl_code) [op:union]
 
 Code template:
 
@@ -341,7 +343,7 @@ Code template:
 
 
 
-=item * Array::AsObject::union (perl_code)
+=item * Array::AsObject::union (perl_code) [op:union]
 
 Code template:
 
@@ -349,7 +351,7 @@ Code template:
 
 
 
-=item * Set::Object::union (perl_code)
+=item * Set::Object::union (perl_code) [op:union]
 
 Code template:
 
@@ -357,7 +359,7 @@ Code template:
 
 
 
-=item * Set::Tiny::union (perl_code)
+=item * Set::Tiny::union (perl_code) [op:union]
 
 Code template:
 
@@ -365,7 +367,7 @@ Code template:
 
 
 
-=item * Array::Utils::array_diff (perl_code)
+=item * Array::Utils::array_diff (perl_code) [op:symdiff]
 
 Code template:
 
@@ -373,7 +375,7 @@ Code template:
 
 
 
-=item * Set::Scalar::symmetric_difference (perl_code)
+=item * Set::Scalar::symmetric_difference (perl_code) [op:symdiff]
 
 Code template:
 
@@ -381,7 +383,7 @@ Code template:
 
 
 
-=item * List::MoreUtils::PP::singleton (perl_code)
+=item * List::MoreUtils::PP::singleton (perl_code) [op:symdiff]
 
 Function call template:
 
@@ -389,7 +391,7 @@ Function call template:
 
 
 
-=item * List::MoreUtils::XS::singleton (perl_code)
+=item * List::MoreUtils::XS::singleton (perl_code) [op:symdiff]
 
 Function call template:
 
@@ -397,7 +399,7 @@ Function call template:
 
 
 
-=item * Array::Set::set_symdiff (perl_code)
+=item * Array::Set::set_symdiff (perl_code) [op:symdiff]
 
 Function call template:
 
@@ -405,7 +407,7 @@ Function call template:
 
 
 
-=item * Set::Array::symmetric_difference (perl_code)
+=item * Set::Array::symmetric_difference (perl_code) [op:symdiff]
 
 Code template:
 
@@ -413,7 +415,7 @@ Code template:
 
 
 
-=item * Array::AsObject::symmetric_difference (perl_code)
+=item * Array::AsObject::symmetric_difference (perl_code) [op:symdiff]
 
 Code template:
 
@@ -421,7 +423,7 @@ Code template:
 
 
 
-=item * Set::Object::symmetric_difference (perl_code)
+=item * Set::Object::symmetric_difference (perl_code) [op:symdiff]
 
 Code template:
 
@@ -429,7 +431,7 @@ Code template:
 
 
 
-=item * Set::Tiny::symmetric_difference (perl_code)
+=item * Set::Tiny::symmetric_difference (perl_code) [op:symdiff]
 
 Code template:
 
@@ -437,7 +439,7 @@ Code template:
 
 
 
-=item * Array::Utils::array_minus (perl_code)
+=item * Array::Utils::array_minus (perl_code) [op:diff]
 
 Code template:
 
@@ -445,7 +447,7 @@ Code template:
 
 
 
-=item * Set::Scalar::difference (perl_code)
+=item * Set::Scalar::difference (perl_code) [op:diff]
 
 Code template:
 
@@ -453,7 +455,7 @@ Code template:
 
 
 
-=item * Array::Set::set_diff (perl_code)
+=item * Array::Set::set_diff (perl_code) [op:diff]
 
 Function call template:
 
@@ -461,7 +463,7 @@ Function call template:
 
 
 
-=item * Set::Array::difference (perl_code)
+=item * Set::Array::difference (perl_code) [op:diff]
 
 Code template:
 
@@ -469,7 +471,7 @@ Code template:
 
 
 
-=item * Array::AsObject::difference (perl_code)
+=item * Array::AsObject::difference (perl_code) [op:diff]
 
 Code template:
 
@@ -477,7 +479,7 @@ Code template:
 
 
 
-=item * Set::Object::difference (perl_code)
+=item * Set::Object::difference (perl_code) [op:diff]
 
 Code template:
 
@@ -485,7 +487,7 @@ Code template:
 
 
 
-=item * Set::Tiny::difference (perl_code)
+=item * Set::Tiny::difference (perl_code) [op:diff]
 
 Code template:
 
@@ -493,7 +495,7 @@ Code template:
 
 
 
-=item * Array::Utils::intersect (perl_code)
+=item * Array::Utils::intersect (perl_code) [op:intersect]
 
 Code template:
 
@@ -501,7 +503,7 @@ Code template:
 
 
 
-=item * Set::Scalar::intersection (perl_code)
+=item * Set::Scalar::intersection (perl_code) [op:intersect]
 
 Code template:
 
@@ -509,7 +511,7 @@ Code template:
 
 
 
-=item * Array::Set::set_intersect (perl_code)
+=item * Array::Set::set_intersect (perl_code) [op:intersect]
 
 Function call template:
 
@@ -517,7 +519,7 @@ Function call template:
 
 
 
-=item * Set::Array::intersection (perl_code)
+=item * Set::Array::intersection (perl_code) [op:intersect]
 
 Code template:
 
@@ -525,7 +527,7 @@ Code template:
 
 
 
-=item * Array::AsObject::intersection (perl_code)
+=item * Array::AsObject::intersection (perl_code) [op:intersect]
 
 Code template:
 
@@ -533,7 +535,7 @@ Code template:
 
 
 
-=item * Set::Object::intersection (perl_code)
+=item * Set::Object::intersection (perl_code) [op:intersect]
 
 Code template:
 
@@ -541,7 +543,7 @@ Code template:
 
 
 
-=item * Set::Tiny::intersection (perl_code)
+=item * Set::Tiny::intersection (perl_code) [op:intersect]
 
 Code template:
 
@@ -549,112 +551,115 @@ Code template:
 
 
 
+=back
+
+=head1 BENCHMARK DATASETS
+
+=over
+
+=item * num10
+
+=item * num100
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m SetOperationModules >>):
 
- +-----+--------------------------------------------------------------------------+------------+--------------+---------+---------+
- | seq | name                                                                     | rate       | time         | errors  | samples |
- +-----+--------------------------------------------------------------------------+------------+--------------+---------+---------+
- | 31  | {dataset=>"num100",participant=>"Array::AsObject::symmetric_difference"} | 57.6       | 17.3ms       | 6.5e-06 | 20      |
- | 59  | {dataset=>"num100",participant=>"Array::AsObject::intersection"}         | 118        | 8.5ms        | 6.2e-06 | 20      |
- | 45  | {dataset=>"num100",participant=>"Array::AsObject::difference"}           | 240        | 4.16ms       | 2.6e-06 | 20      |
- | 57  | {dataset=>"num100",participant=>"Set::Array::intersection"}              | 349        | 2.87ms       | 2.9e-06 | 20      |
- | 41  | {dataset=>"num100",participant=>"Array::Set::set_diff"}                  | 822        | 1.22ms       | 1.1e-06 | 20      |
- | 55  | {dataset=>"num100",participant=>"Array::Set::set_intersect"}             | 1.21e+03   | 0.827ms      | 6.9e-07 | 20      |
- | 27  | {dataset=>"num100",participant=>"Array::Set::set_symdiff"}               | 1.23e+03   | 0.81ms       | 4.8e-07 | 20      |
- | 53  | {dataset=>"num100",participant=>"Set::Scalar::intersection"}             | 1.27e+03   | 0.785ms      | 6.4e-07 | 20      |
- | 3   | {dataset=>"num100",participant=>"Set::Scalar::union"}                    | 1.32e+03   | 0.756ms      | 2.7e-07 | 20      |
- | 39  | {dataset=>"num100",participant=>"Set::Scalar::difference"}               | 1.38e+03   | 0.723ms      | 6.6e-07 | 22      |
- | 9   | {dataset=>"num100",participant=>"Array::Set::set_union"}                 | 1.69e+03   | 0.59ms       | 2.7e-07 | 20      |
- | 21  | {dataset=>"num100",participant=>"Set::Scalar::symmetric_difference"}     | 1.89e+03   | 0.53ms       | 2.7e-07 | 20      |
- | 30  | {dataset=>"num10",participant=>"Array::AsObject::symmetric_difference"}  | 2.58e+03   | 0.387ms      | 2.1e-07 | 20      |
- | 58  | {dataset=>"num10",participant=>"Array::AsObject::intersection"}          | 5.86e+03   | 0.171ms      | 2.1e-07 | 20      |
- | 52  | {dataset=>"num10",participant=>"Set::Scalar::intersection"}              | 6.64e+03   | 0.151ms      | 2.1e-07 | 20      |
- | 2   | {dataset=>"num10",participant=>"Set::Scalar::union"}                     | 6.8e+03    | 0.147ms      | 2.1e-07 | 20      |
- | 38  | {dataset=>"num10",participant=>"Set::Scalar::difference"}                | 7.08e+03   | 0.141ms      | 5.3e-08 | 20      |
- | 13  | {dataset=>"num100",participant=>"Array::AsObject::union"}                | 7.22e+03   | 0.138ms      | 4.6e-08 | 27      |
- | 33  | {dataset=>"num100",participant=>"Set::Object::symmetric_difference"}     | 8.01e+03   | 0.125ms      | 2.1e-07 | 20      |
- | 43  | {dataset=>"num100",participant=>"Set::Array::difference"}                | 8.17e+03   | 0.122ms      | 4.8e-08 | 25      |
- | 29  | {dataset=>"num100",participant=>"Set::Array::symmetric_difference"}      | 8.49e+03   | 0.118ms      | 2.1e-07 | 20      |
- | 61  | {dataset=>"num100",participant=>"Set::Object::intersection"}             | 8.57e+03   | 0.117ms      | 5.3e-08 | 20      |
- | 15  | {dataset=>"num100",participant=>"Set::Object::union"}                    | 9.78e+03   | 0.102ms      | 1.1e-07 | 20      |
- | 26  | {dataset=>"num10",participant=>"Array::Set::set_symdiff"}                | 1.07e+04   | 0.0936ms     | 1.1e-07 | 20      |
- | 20  | {dataset=>"num10",participant=>"Set::Scalar::symmetric_difference"}      | 10751.7    | 0.0930088ms  | 0       | 20      |
- | 54  | {dataset=>"num10",participant=>"Array::Set::set_intersect"}              | 1.1e+04    | 0.0906ms     | 1e-07   | 21      |
- | 35  | {dataset=>"num100",participant=>"Set::Tiny::symmetric_difference"}       | 1.13e+04   | 0.0883ms     | 1.3e-07 | 20      |
- | 11  | {dataset=>"num100",participant=>"Set::Array::union"}                     | 1.17e+04   | 0.0857ms     | 9.9e-08 | 23      |
- | 44  | {dataset=>"num10",participant=>"Array::AsObject::difference"}            | 1.2e+04    | 0.0834ms     | 7.8e-08 | 21      |
- | 47  | {dataset=>"num100",participant=>"Set::Object::difference"}               | 1.24e+04   | 0.0809ms     | 8e-08   | 20      |
- | 49  | {dataset=>"num100",participant=>"Set::Tiny::difference"}                 | 1.27e+04   | 0.079ms      | 1.1e-07 | 20      |
- | 17  | {dataset=>"num100",participant=>"Set::Tiny::union"}                      | 1.27e+04   | 0.0787ms     | 1.1e-07 | 20      |
- | 63  | {dataset=>"num100",participant=>"Set::Tiny::intersection"}               | 1.33e+04   | 0.0753ms     | 1.3e-07 | 22      |
- | 8   | {dataset=>"num10",participant=>"Array::Set::set_union"}                  | 14358.76   | 0.06964389ms | 1.2e-11 | 20      |
- | 40  | {dataset=>"num10",participant=>"Array::Set::set_diff"}                   | 14918.5    | 0.0670308ms  | 0       | 23      |
- | 23  | {dataset=>"num100",participant=>"List::MoreUtils::PP::singleton"}        | 1.8e+04    | 0.0556ms     | 2.3e-08 | 26      |
- | 19  | {dataset=>"num100",participant=>"Array::Utils::array_diff"}              | 1.8e+04    | 0.055ms      | 3e-07   | 23      |
- | 56  | {dataset=>"num10",participant=>"Set::Array::intersection"}               | 1.93e+04   | 0.0519ms     | 2.5e-08 | 23      |
- | 37  | {dataset=>"num100",participant=>"Array::Utils::array_minus"}             | 20417.8    | 0.0489768ms  | 3.5e-11 | 22      |
- | 51  | {dataset=>"num100",participant=>"Array::Utils::intersect"}               | 2.057e+04  | 0.04862ms    | 1.3e-08 | 20      |
- | 5   | {dataset=>"num100",participant=>"List::MoreUtils::PP::uniq"}             | 2.42e+04   | 0.0413ms     | 6.5e-08 | 21      |
- | 25  | {dataset=>"num100",participant=>"List::MoreUtils::XS::singleton"}        | 3.12e+04   | 0.032ms      | 5.3e-08 | 20      |
- | 42  | {dataset=>"num10",participant=>"Set::Array::difference"}                 | 3.44e+04   | 0.0291ms     | 4e-08   | 20      |
- | 28  | {dataset=>"num10",participant=>"Set::Array::symmetric_difference"}       | 3.81e+04   | 0.0262ms     | 1.3e-08 | 21      |
- | 7   | {dataset=>"num100",participant=>"List::MoreUtils::XS::uniq"}             | 4.04e+04   | 0.0248ms     | 3.3e-08 | 21      |
- | 32  | {dataset=>"num10",participant=>"Set::Object::symmetric_difference"}      | 4.223e+04  | 0.02368ms    | 6.5e-09 | 21      |
- | 12  | {dataset=>"num10",participant=>"Array::AsObject::union"}                 | 4.425e+04  | 0.0226ms     | 6.7e-09 | 20      |
- | 10  | {dataset=>"num10",participant=>"Set::Array::union"}                      | 4.7e+04    | 0.0213ms     | 2.7e-08 | 20      |
- | 60  | {dataset=>"num10",participant=>"Set::Object::intersection"}              | 6.07e+04   | 0.0165ms     | 6.5e-09 | 21      |
- | 14  | {dataset=>"num10",participant=>"Set::Object::union"}                     | 7.07e+04   | 0.0141ms     | 2.4e-08 | 25      |
- | 46  | {dataset=>"num10",participant=>"Set::Object::difference"}                | 76941      | 0.012997ms   | 4.6e-11 | 20      |
- | 34  | {dataset=>"num10",participant=>"Set::Tiny::symmetric_difference"}        | 7.86e+04   | 0.0127ms     | 6.7e-09 | 20      |
- | 48  | {dataset=>"num10",participant=>"Set::Tiny::difference"}                  | 8.92e+04   | 0.0112ms     | 1.3e-08 | 20      |
- | 16  | {dataset=>"num10",participant=>"Set::Tiny::union"}                       | 9.59e+04   | 0.0104ms     | 3e-08   | 20      |
- | 62  | {dataset=>"num10",participant=>"Set::Tiny::intersection"}                | 9.868e+04  | 0.01013ms    | 3.2e-09 | 22      |
- | 18  | {dataset=>"num10",participant=>"Array::Utils::array_diff"}               | 1.4e+05    | 0.00713ms    | 3.1e-09 | 23      |
- | 1   | {dataset=>"num100",participant=>"Array::Utils::unique"}                  | 1.56e+05   | 0.0064ms     | 1e-08   | 20      |
- | 22  | {dataset=>"num10",participant=>"List::MoreUtils::PP::singleton"}         | 1.5707e+05 | 0.0063665ms  | 4.6e-11 | 21      |
- | 36  | {dataset=>"num10",participant=>"Array::Utils::array_minus"}              | 1.7408e+05 | 0.0057444ms  | 4.7e-11 | 21      |
- | 50  | {dataset=>"num10",participant=>"Array::Utils::intersect"}                | 1.775e+05  | 0.005633ms   | 1.6e-09 | 21      |
- | 4   | {dataset=>"num10",participant=>"List::MoreUtils::PP::uniq"}              | 2.08e+05   | 0.00482ms    | 1.3e-08 | 21      |
- | 24  | {dataset=>"num10",participant=>"List::MoreUtils::XS::singleton"}         | 2.57e+05   | 0.00389ms    | 6.7e-09 | 20      |
- | 6   | {dataset=>"num10",participant=>"List::MoreUtils::XS::uniq"}              | 3.45e+05   | 0.0029ms     | 3.3e-09 | 20      |
- | 0   | {dataset=>"num10",participant=>"Array::Utils::unique"}                   | 4.81e+05   | 0.00208ms    | 3.3e-09 | 21      |
- +-----+--------------------------------------------------------------------------+------------+--------------+---------+---------+
+ +---------------------------------------+---------+-----------+-----------+------------+---------+---------+
+ | participant                           | dataset | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +---------------------------------------+---------+-----------+-----------+------------+---------+---------+
+ | Array::AsObject::symmetric_difference | num100  |     104.6 | 9.564     |      1     | 9.1e-07 |      20 |
+ | Array::AsObject::intersection         | num100  |     213.8 | 4.677     |      2.045 | 4.3e-07 |      20 |
+ | Array::AsObject::difference           | num100  |     436   | 2.3       |      4.17  | 2.7e-07 |      20 |
+ | Set::Array::intersection              | num100  |     615   | 1.63      |      5.88  | 1.1e-06 |      20 |
+ | Array::Set::set_diff                  | num100  |    1400   | 0.713     |     13.4   | 4.3e-07 |      20 |
+ | Set::Scalar::intersection             | num100  |    1870   | 0.536     |     17.8   | 2.1e-07 |      20 |
+ | Array::Set::set_intersect             | num100  |    1880   | 0.533     |     17.9   | 2.1e-07 |      21 |
+ | Array::Set::set_symdiff               | num100  |    1910   | 0.524     |     18.3   | 2.1e-07 |      20 |
+ | Set::Scalar::union                    | num100  |    1960   | 0.51      |     18.8   | 2.7e-07 |      20 |
+ | Set::Scalar::difference               | num100  |    2050   | 0.487     |     19.6   | 2.4e-07 |      24 |
+ | Array::Set::set_union                 | num100  |    2660   | 0.376     |     25.4   | 2.1e-07 |      20 |
+ | Set::Scalar::symmetric_difference     | num100  |    2800   | 0.357     |     26.8   | 2.3e-07 |      27 |
+ | Array::AsObject::symmetric_difference | num10   |    4690   | 0.213     |     44.9   | 5.3e-08 |      20 |
+ | Set::Scalar::intersection             | num10   |   11000   | 0.094     |    100     | 1.1e-07 |      32 |
+ | Array::AsObject::intersection         | num10   |   10600   | 0.0942    |    102     | 2.7e-08 |      20 |
+ | Set::Scalar::union                    | num10   |   11000   | 0.093     |    100     | 1.1e-07 |      29 |
+ | Array::AsObject::union                | num100  |   11000   | 0.091     |    110     | 1.1e-07 |      20 |
+ | Set::Scalar::difference               | num10   |   11000   | 0.088     |    110     | 1.1e-07 |      20 |
+ | Set::Object::symmetric_difference     | num100  |   11773.7 | 0.0849352 |    112.601 | 9.6e-12 |      20 |
+ | Set::Array::difference                | num100  |   12000   | 0.084     |    110     | 1.1e-07 |      31 |
+ | Set::Object::intersection             | num100  |   12000   | 0.081     |    120     | 1.1e-07 |      20 |
+ | Set::Array::symmetric_difference      | num100  |   13000   | 0.08      |    120     | 1.1e-07 |      20 |
+ | Set::Object::union                    | num100  |   14000   | 0.07      |    140     | 2.1e-07 |      20 |
+ | Set::Tiny::symmetric_difference       | num100  |   16000   | 0.063     |    150     | 9.5e-08 |      25 |
+ | Set::Object::difference               | num100  |   17000   | 0.0589    |    162     | 2.5e-08 |      22 |
+ | Array::Set::set_symdiff               | num10   |   17100   | 0.0584    |    164     | 2.4e-08 |      24 |
+ | Set::Scalar::symmetric_difference     | num10   |   17200   | 0.058     |    165     | 2.7e-08 |      20 |
+ | Set::Tiny::difference                 | num100  |   17000   | 0.058     |    170     | 1.1e-07 |      20 |
+ | Set::Tiny::union                      | num100  |   17000   | 0.057     |    170     | 1.1e-07 |      20 |
+ | Set::Array::union                     | num100  |   17000   | 0.057     |    170     | 1.1e-07 |      20 |
+ | Array::Set::set_intersect             | num10   |   18000   | 0.056     |    170     | 1.1e-07 |      20 |
+ | Set::Tiny::intersection               | num100  |   18000   | 0.054     |    180     | 1.1e-07 |      20 |
+ | Array::AsObject::difference           | num10   |   21800   | 0.0459    |    208     | 1.1e-08 |      28 |
+ | Array::Set::set_union                 | num10   |   24144.1 | 0.0414179 |    230.91  | 1.1e-11 |      20 |
+ | List::MoreUtils::PP::singleton        | num100  |   25300   | 0.0395    |    242     | 1.1e-08 |      30 |
+ | Array::Utils::array_diff              | num100  |   25806.5 | 0.0387499 |    246.808 |   1e-11 |      21 |
+ | Array::Set::set_diff                  | num10   |   28000   | 0.036     |    270     | 3.8e-08 |      22 |
+ | Array::Utils::array_minus             | num100  |   29000   | 0.035     |    280     | 4.2e-08 |      33 |
+ | Array::Utils::intersect               | num100  |   29300   | 0.0341    |    280     | 3.1e-08 |      33 |
+ | List::MoreUtils::PP::uniq             | num100  |   33300   | 0.03      |    319     | 9.9e-09 |      36 |
+ | Set::Array::intersection              | num10   |   35471.5 | 0.0281917 |    339.242 |   1e-11 |      20 |
+ | List::MoreUtils::XS::singleton        | num100  |   44200   | 0.0226    |    423     | 5.8e-09 |      26 |
+ | List::MoreUtils::XS::uniq             | num100  |   56700   | 0.0176    |    542     | 5.8e-09 |      26 |
+ | Set::Array::difference                | num10   |   61800   | 0.0162    |    591     | 6.7e-09 |      20 |
+ | Set::Array::symmetric_difference      | num10   |   68300   | 0.0146    |    653     | 6.7e-09 |      20 |
+ | Set::Object::symmetric_difference     | num10   |   70100   | 0.0143    |    670     | 6.4e-09 |      22 |
+ | Array::AsObject::union                | num10   |   72000   | 0.0139    |    689     | 6.1e-09 |      24 |
+ | Set::Array::union                     | num10   |   86820.4 | 0.011518  |    830.334 | 9.8e-12 |      22 |
+ | Set::Object::intersection             | num10   |  100000   | 0.00996   |    960     | 3.3e-09 |      21 |
+ | Set::Object::union                    | num10   |  114000   | 0.00874   |   1090     | 3.3e-09 |      20 |
+ | Set::Object::difference               | num10   |  126000   | 0.00797   |   1200     | 2.7e-09 |      30 |
+ | Set::Tiny::symmetric_difference       | num10   |  128000   | 0.00782   |   1220     | 7.8e-09 |      33 |
+ | Set::Tiny::difference                 | num10   |  138000   | 0.00724   |   1320     | 3.3e-09 |      20 |
+ | Set::Tiny::union                      | num10   |  140000   | 0.0069    |   1400     | 7.6e-09 |      35 |
+ | Set::Tiny::intersection               | num10   |  150000   | 0.0065    |   1500     | 9.8e-09 |      21 |
+ | Array::Utils::array_diff              | num10   |  209380   | 0.0047759 |   2002.5   | 9.5e-12 |      20 |
+ | List::MoreUtils::PP::singleton        | num10   |  220000   | 0.0045    |   2100     | 5.5e-09 |      29 |
+ | Array::Utils::unique                  | num100  |  235000   | 0.00426   |   2250     | 1.7e-09 |      20 |
+ | Array::Utils::array_minus             | num10   |  254190   | 0.003934  |   2431.1   | 9.8e-12 |      20 |
+ | Array::Utils::intersect               | num10   |  258200   | 0.003872  |   2470     | 4.7e-11 |      20 |
+ | List::MoreUtils::PP::uniq             | num10   |  290000   | 0.0034    |   2800     |   4e-09 |      31 |
+ | List::MoreUtils::XS::singleton        | num10   |  400000   | 0.0025    |   3900     | 3.3e-09 |      20 |
+ | List::MoreUtils::XS::uniq             | num10   |  501120   | 0.0019955 |   4792.6   | 9.3e-12 |      20 |
+ | Array::Utils::unique                  | num10   |  750000   | 0.0013    |   7100     | 1.7e-09 |      20 |
+ +---------------------------------------+---------+-----------+-----------+------------+---------+---------+
 
 
-Benchmark module startup overhead:
+Benchmark module startup overhead (C<< bencher -m SetOperationModules --module-startup >>):
 
- +-----+---------------------+--------+-------------------+---------+---------+
- | seq | name                | time   | mod_overhead_time | errors  | samples |
- +-----+---------------------+--------+-------------------+---------+---------+
- | 7   | Array::AsObject     | 22.3ms | 17ms              | 4.1e-05 | 21      |
- | 6   | Set::Array          | 21.7ms | 16.4ms            | 6.6e-05 | 20      |
- | 8   | Set::Object         | 19ms   | 13ms              | 8e-05   | 20      |
- | 2   | Set::Scalar         | 16.5ms | 11.2ms            | 2.4e-05 | 21      |
- | 4   | List::MoreUtils     | 16ms   | 11ms              | 0.00014 | 20      |
- | 5   | Array::Set          | 13.6ms | 8.25ms            | 2.6e-05 | 20      |
- | 3   | List::MoreUtils::PP | 9.5ms  | 4.2ms             | 3.7e-05 | 20      |
- | 9   | Set::Tiny           | 6.48ms | 1.17ms            | 1.6e-05 | 20      |
- | 1   | Array::Utils        | 6.2ms  | 0.94ms            | 3.4e-05 | 20      |
- | 0   | perl -e1 (baseline) | 5.3ms  | 0ms               | 8.7e-05 | 20      |
- +-----+---------------------+--------+-------------------+---------+---------+
+ +---------------------+-----------+------------------------+------------+---------+---------+
+ | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+-----------+------------------------+------------+---------+---------+
+ | Set::Array          |      15   |                   12.5 |        1   | 2.1e-05 |      20 |
+ | Array::AsObject     |      14   |                   11.5 |        1   | 5.4e-05 |      20 |
+ | Set::Object         |      12   |                    9.5 |        1.2 | 2.6e-05 |      21 |
+ | Set::Scalar         |      11   |                    8.5 |        1.3 | 3.1e-05 |      20 |
+ | List::MoreUtils     |       9.9 |                    7.4 |        1.5 | 3.6e-05 |      21 |
+ | Array::Set          |       8.6 |                    6.1 |        1.7 | 1.3e-05 |      20 |
+ | List::MoreUtils::PP |       5.5 |                    3   |        2.7 | 1.1e-05 |      20 |
+ | Set::Tiny           |       3.8 |                    1.3 |        3.9 | 8.7e-06 |      20 |
+ | Array::Utils        |       3.5 |                    1   |        4.2 |   2e-05 |      20 |
+ | perl -e1 (baseline) |       2.5 |                    0   |        5.8 |   7e-06 |      20 |
+ +---------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
 Packaging a benchmark script as a Bencher scenario makes it convenient to include/exclude/add participants/datasets (either via CLI or Perl code), send the result to a central repository, among others . See L<Bencher> and L<bencher> (CLI) for more details.
 
-=head1 SEE ALSO
-
-L<Benchmark::Featureset::SetOps>
-
-Excluded modules: L<Set::Bag> (expects hashes instead of arrays),
-L<Set::SortedArray> (members are sorted).
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenario-SetOperationModules>.
@@ -671,6 +676,13 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Benchmark::Featureset::SetOps>
+
+Excluded modules: L<Set::Bag> (expects hashes instead of arrays),
+L<Set::SortedArray> (members are sorted).
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
